Crate use_oci_layout

Crate use_oci_layout 

use-oci-layout

use-oci-layout provides OCI image layout primitives for layout versions, blobs, index, refs, and lexical path helpers.

It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.

License

Licensed under either of the following, at your option:

  • Apache License, Version 2.0
  • MIT license

Structs

BlobsDirectory
Marker for the blobs directory.
IndexFile
Marker for index.json.
LayoutVersion
OCI image layout version marker.
OciLayoutPaths
Lexical OCI image layout paths. This type does not create directories or files.
RefsDirectory
Marker for the optional refs directory.

Enums

LayoutError
Errors returned when layout metadata is invalid.