use-oci-layout
use-oci-layout provides OCI image layout primitives for layout versions, blobs, index, refs, and lexical path helpers.
It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.
License
Licensed under either of the following, at your option:
- Apache License, Version 2.0
- MIT license
Structs
- Blobs
Directory - Marker for the
blobsdirectory. - Index
File - Marker for
index.json. - Layout
Version - OCI image layout version marker.
- OciLayout
Paths - Lexical OCI image layout paths. This type does not create directories or files.
- Refs
Directory - Marker for the optional
refsdirectory.
Enums
- Layout
Error - Errors returned when layout metadata is invalid.